Builtin features - Faber 1.0 documentation

###  |

# Builtin features

The following features are provided by Faber and its built-in tools.

`cppflags`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Generic preprocessing flags. They are passed through to the compiler, unmodified.

`cflags`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Generic C compiler flags. They are passed through to the compiler, unmodified.

`cxxflags`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Generic C++ compiler flags. They are passed through to the compiler, unmodified.

`cxxstd`

Defined in: | faber.tools.cxx
Attributes: | incidental
Possible values:
| 98, 03, 11, 14, 17

  C++ standard version to be used.

`ldflags`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Generic linker flags. They are passed through to the compiler / linker, unmodified.

`define`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Macro definitions. They are passed through to the compiler / preprocessor, unmodified.

`linkpath`

Defined in: | faber.tools.compiler
Attributes: | multi,path,incidental

  Library search paths. They are passed through to the compiler / linker, unmodified.

`include`

Defined in: | faber.tools.compiler
Attributes: | multi,path,incidental

  Header search paths. They are passed through to the compiler / preprocessor, unmodified.

`libs`

Defined in: | faber.tools.compiler
Attributes: | multi,incidental

  Libraries to be linked to. They are passed through to the compiler / linker, unmodified.

`link`

Defined in: | faber.tools.compiler
Possible values:
| 'static', 'shared'

  Link type for libraries.

`target.os`

Defined in: | faber.tools.compiler

  The target OS of the compiler. Examples: Linux, Windows, Darwin.

`target.arch`

Defined in: | faber.tools.compiler

  The target architecture of the compiler. Examples: x86_64, x86, arm, aarm64.

`runpath`

Defined in: | faber.tools.compiler
Attributes: | multi,path,incidental

  The library search path used during application execution.

`pythonpath`

Defined in: | faber.tools.python
Attributes: | multi,path,incidental

  The Python module search path used during application execution.